@@ -20,10 +20,7 @@
 #ifndef __EMPATHY_BAD_PASSWORD_DIALOG_H__
 #define __EMPATHY_BAD_PASSWORD_DIALOG_H__
 
-#include <glib-object.h>
-#include <gtk/gtk.h>
-
-#include <libempathy-gtk/empathy-base-password-dialog.h>
+#include "empathy-base-password-dialog.h"
 
 G_BEGIN_DECLS
 
