@@ -21,11 +21,10 @@
  */
 
 #include "config.h"
-
-#include <libempathy/empathy-utils.h>
-
 #include "empathy-cell-renderer-activatable.h"
 
+#include "empathy-utils.h"
+
 enum {
   PATH_ACTIVATED,
   LAST_SIGNAL
