@@ -54,7 +54,8 @@ enum
 
 enum {
    PAGE_SEARCH_RESULTS,
-   PAGE_NO_MATCH
+   PAGE_NO_MATCH,
+   PAGE_NOT_SUPPORTED,
 };
 
 typedef struct _EmpathyContactSearchDialogPrivate EmpathyContactSearchDialogPrivate;
@@ -69,7 +70,6 @@ struct _EmpathyContactSearchDialogPrivate
   GtkWidget *spinner;
   GtkWidget *add_button;
   GtkWidget *find_button;
-  GtkWidget *no_contact_found;
   GtkWidget *search_entry;
   /* GtkWidget *server_entry; */
   GtkWidget *message;
@@ -103,10 +103,16 @@ on_searcher_reset (GObject *source_object,
   if (error != NULL)
     {
       DEBUG ("Failed to reset the TpContactSearch: %s", error->message);
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
+          PAGE_NOT_SUPPORTED);
+
       g_error_free (error);
       return;
     }
 
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
+      PAGE_SEARCH_RESULTS);
+
   search = g_hash_table_new (g_str_hash, g_str_equal);
 
   search_criteria = gtk_entry_get_text (GTK_ENTRY (priv->search_entry));
@@ -315,16 +321,23 @@ on_searcher_created (GObject *source_object,
   if (error != NULL)
     {
       DEBUG ("Failed to create a TpContactSearch: %s", error->message);
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
+          PAGE_NOT_SUPPORTED);
+
       g_error_free (error);
       return;
     }
 
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
+      PAGE_SEARCH_RESULTS);
+
   g_signal_connect (priv->searcher, "search-results-received",
       G_CALLBACK (_search_results_received), self);
   g_signal_connect (priv->searcher, "notify::state",
       G_CALLBACK (_on_search_state_changed_cb), self);
 
   gtk_widget_set_sensitive (priv->find_button, TRUE);
+  gtk_widget_set_sensitive (priv->search_entry, TRUE);
 }
 
 static void
@@ -373,6 +386,7 @@ _account_chooser_changed (EmpathyAccountChooser *chooser,
 
   /* gtk_widget_set_sensitive (priv->server_entry, can_set_server); */
   gtk_widget_set_sensitive (priv->find_button, FALSE);
+  gtk_widget_set_sensitive (priv->search_entry, FALSE);
 
   DEBUG ("New account is %s", tp_proxy_get_object_path (account));
 
@@ -506,6 +520,24 @@ on_profile_button_clicked_cb (EmpathyCellRendererActivatable *cell,
   g_object_unref (factory);
 }
 
+static void
+append_message_page (EmpathyContactSearchDialog *self,
+    const gchar *message)
+{
+  EmpathyContactSearchDialogPrivate *priv = GET_PRIVATE (self);
+  GtkWidget *label;
+  gchar *tmp;
+
+  label = gtk_label_new (NULL);
+  tmp = g_strdup_printf ("<b><span size='xx-large'>%s</span></b>", message);
+  gtk_label_set_markup (GTK_LABEL (label), tmp);
+  g_free (tmp);
+
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+
+  gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), label, NULL);
+}
+
 static void
 empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
 {
@@ -515,7 +547,6 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
   GtkTreeViewColumn *col;
   GtkTreeSelection *selection;
   GtkSizeGroup *size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-  gchar *tmp;
 
   /* Title */
   gtk_window_set_title (GTK_WINDOW (self), _("Search contacts"));
@@ -622,19 +653,11 @@ empathy_contact_search_dialog_init (EmpathyContactSearchDialog *self)
 
   gtk_container_add (GTK_CONTAINER (scrolled_window), priv->tree_view);
 
-  priv->no_contact_found = gtk_label_new (NULL);
-  tmp = g_strdup_printf ("<b><span size='xx-large'>%s</span></b>",
-      _("No contacts found"));
-  gtk_label_set_markup (GTK_LABEL (priv->no_contact_found), tmp);
-  g_free (tmp);
-
-  gtk_label_set_ellipsize (GTK_LABEL (priv->no_contact_found),
-      PANGO_ELLIPSIZE_END);
-
   gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), scrolled_window,
       NULL);
-  gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook),
-      priv->no_contact_found, NULL);
+
+  append_message_page (self, _("No contacts found"));
+  append_message_page (self, _("Contact search is not supported on this account"));
 
   gtk_box_pack_start (GTK_BOX (vbox), priv->notebook, TRUE, TRUE, 3);
 
