@@ -732,12 +732,13 @@ theme_adium_add_html (EmpathyThemeAdium *self,
   bytes = g_resources_lookup_data ("/org/gnome/Empathy/Chat/empathy-chat.js",
       G_RESOURCE_LOOKUP_FLAGS_NONE,
       NULL);
-  if (bytes == NULL)
-    return;
 
-  js = (const gchar *) g_bytes_get_data (bytes, NULL);
-  g_string_prepend (string, js);
-  g_bytes_unref (bytes);
+  if (bytes != NULL)
+    {
+      js = (const gchar *) g_bytes_get_data (bytes, NULL);
+      g_string_prepend (string, js);
+      g_bytes_unref (bytes);
+    }
 
   script = g_string_free (string, FALSE);
   webkit_web_view_execute_script (WEBKIT_WEB_VIEW (self), script);
