@@ -40,8 +40,6 @@
 
 G_BEGIN_DECLS
 
-#define ACCOUNT_WIDGETS_RESOURCES_PREFIX "/org/gnome/AccountWidgets"
-
 #define EMPATHY_RECT_IS_ON_SCREEN(x,y,w,h) ((x) + (w) > 0 && \
               (y) + (h) > 0 && \
               (x) < gdk_screen_width () && \
@@ -54,31 +52,12 @@ typedef void (*EmpathyPixbufAvatarFromIndividualCb) (
 
 void empathy_gtk_init (void);
 
-/* Glade */
-GtkBuilder * empathy_builder_get_file (const gchar *filename,
-    const gchar *first_object,
-    ...);
-GtkBuilder * empathy_builder_get_resource (const gchar *resourcename,
-    const gchar *first_object,
-    ...);
-void empathy_builder_connect (GtkBuilder *gui,
-    gpointer user_data,
-    const gchar *first_object,
-    ...);
-GtkWidget * empathy_builder_unref_and_keep_widget (GtkBuilder *gui,
-    GtkWidget *root);
-
 /* Pixbufs */
 const gchar * empathy_icon_name_for_presence (
     TpConnectionPresenceType presence);
 const gchar * empathy_icon_name_for_contact (EmpathyContact *contact);
 const gchar * empathy_icon_name_for_individual (FolksIndividual *individual);
 const gchar * empathy_protocol_name_for_contact (EmpathyContact *contact);
-GdkPixbuf * empathy_pixbuf_from_data (gchar *data,
-    gsize data_size);
-GdkPixbuf * empathy_pixbuf_from_data_and_mime (gchar *data,
-    gsize data_size,
-    gchar **mime_type);
 void empathy_pixbuf_avatar_from_individual_scaled_async (
     FolksIndividual *individual,
     gint width,
@@ -99,29 +78,11 @@ GdkPixbuf * empathy_pixbuf_contact_status_icon_with_icon_name (
     EmpathyContact *contact,
     const gchar *icon_name,
     gboolean show_protocol);
-GdkPixbuf * empathy_pixbuf_scale_down_if_necessary (GdkPixbuf *pixbuf,
-    gint max_size);
-GdkPixbuf * empathy_pixbuf_from_icon_name (const gchar *icon_name,
-    GtkIconSize icon_size);
-GdkPixbuf * empathy_pixbuf_from_icon_name_sized (const gchar *icon_name,
-    gint size);
-gchar * empathy_filename_from_icon_name (const gchar *icon_name,
-    GtkIconSize icon_size);
-
-/* Windows */
-void empathy_window_present (GtkWindow *window);
-void empathy_window_present_with_time (GtkWindow *window,
-    guint32 timestamp);
-GtkWindow * empathy_get_toplevel_window (GtkWidget *widget);
 
 void empathy_move_to_window_desktop (GtkWindow *window,
     guint32 timestamp);
 
 /* URL */
-gchar * empathy_make_absolute_url (const gchar *url);
-
-gchar * empathy_make_absolute_url_len (const gchar *url,
-    guint len);
 void empathy_url_show (GtkWidget *parent,
     const char *url);
 
