@@ -83,9 +83,6 @@ G_BEGIN_DECLS
 
 #define EMPATHY_PREFS_LOCATION_SCHEMA EMPATHY_PREFS_SCHEMA ".location"
 #define EMPATHY_PREFS_LOCATION_PUBLISH             "publish"
-#define EMPATHY_PREFS_LOCATION_RESOURCE_NETWORK    "resource-network"
-#define EMPATHY_PREFS_LOCATION_RESOURCE_CELL       "resource-cell"
-#define EMPATHY_PREFS_LOCATION_RESOURCE_GPS        "resource-gps"
 #define EMPATHY_PREFS_LOCATION_REDUCE_ACCURACY     "reduce-accuracy"
 
 #define EMPATHY_PREFS_LOGGER_SCHEMA "org.freedesktop.Telepathy.Logger"
