@@ -19,8 +19,7 @@
  */
 
 #include "config.h"
-
-#include <libempathy/empathy-pkg-kit.h>
+#include "empathy-pkg-kit.h"
 
 typedef struct
 {
