@@ -29,14 +29,14 @@
 
 G_BEGIN_DECLS
 
-#define EMPATHY_CHAT_BUS_NAME_SUFFIX "Empathy.Chat"
-#define EMPATHY_CHAT_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_CHAT_BUS_NAME_SUFFIX
+#define EMPATHY_CHAT_TP_BUS_NAME_SUFFIX "Empathy.Chat"
+#define EMPATHY_CHAT_TP_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_CHAT_TP_BUS_NAME_SUFFIX
 
-#define EMPATHY_CALL_BUS_NAME_SUFFIX "Empathy.Call"
-#define EMPATHY_CALL_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_CALL_BUS_NAME_SUFFIX
+#define EMPATHY_CALL_TP_BUS_NAME_SUFFIX "Empathy.Call"
+#define EMPATHY_CALL_TP_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_CALL_TP_BUS_NAME_SUFFIX
 
-#define EMPATHY_FT_BUS_NAME_SUFFIX "Empathy.FileTransfer"
-#define EMPATHY_FT_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_FT_BUS_NAME_SUFFIX
+#define EMPATHY_FT_TP_BUS_NAME_SUFFIX "Empathy.FileTransfer"
+#define EMPATHY_FT_TP_BUS_NAME TP_CLIENT_BUS_NAME_BASE EMPATHY_FT_TP_BUS_NAME_SUFFIX
 
 /* Requesting 1 to 1 text channels */
 void empathy_chat_with_contact_id (TpAccount *account,
