@@ -27,12 +27,11 @@
 #ifndef __EMPATHY_CHAT_WINDOW_H__
 #define __EMPATHY_CHAT_WINDOW_H__
 
-#include <glib-object.h>
 #include <gtk/gtk.h>
-
 #include <telepathy-glib/telepathy-glib.h>
 
-#include <libempathy-gtk/empathy-chat.h>
+#include "empathy-chat.h"
+#include "empathy-individual-manager.h"
 
 G_BEGIN_DECLS
 
