@@ -13,10 +13,9 @@
 #define __EMPATHY_INVITE_PARTICIPANT_DIALOG_H__
 
 #include <gtk/gtk.h>
-
 #include <telepathy-glib/telepathy-glib.h>
 
-#include "libempathy/empathy-tp-chat.h"
+#include "empathy-tp-chat.h"
 
 G_BEGIN_DECLS
 
