@@ -18,18 +18,16 @@
  */
 
 #include "config.h"
+#include "empathy-notifications-approver.h"
 
 #include <glib/gi18n.h>
 
-#include <libempathy-gtk/empathy-notify-manager.h>
-#include <libempathy-gtk/empathy-call-utils.h>
-
+#include "empathy-call-utils.h"
 #include "empathy-event-manager.h"
+#include "empathy-notify-manager.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
-
-#include "empathy-notifications-approver.h"
+#include "empathy-debug.h"
 
 struct _EmpathyNotificationsApproverPrivate
 {
