@@ -28,6 +28,7 @@
 
 #include <glib/gi18n.h>
 #include <tp-account-widgets/tpaw-builder.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
 #include "empathy-client-factory.h"
 #include "empathy-gsettings.h"
@@ -218,12 +219,6 @@ preferences_setup_widgets (EmpathyPreferences *preferences,
 	BIND_SENSITIVE (sound, SOUNDS_ENABLED,
 			"treeview_sounds");
 
-	BIND_SENSITIVE (loc, LOCATION_PUBLISH,
-			"checkbutton_location_resource_network");
-	BIND_SENSITIVE (loc, LOCATION_PUBLISH,
-			"checkbutton_location_resource_cell");
-	BIND_SENSITIVE (loc, LOCATION_PUBLISH,
-			"checkbutton_location_resource_gps");
 	BIND_SENSITIVE (loc, LOCATION_PUBLISH,
 			"checkbutton_location_reduce_accuracy");
 
