@@ -22,6 +22,9 @@
 #include "config.h"
 #include "empathy-status-icon.h"
 
+#include <tp-account-widgets/tpaw-builder.h>
+#include <tp-account-widgets/tpaw-utils.h>
+
 #include "empathy-event-manager.h"
 #include "empathy-gsettings.h"
 #include "empathy-new-call-dialog.h"
@@ -80,7 +83,7 @@ status_icon_update_tooltip (EmpathyStatusIcon *icon)
 		type = tp_account_manager_get_most_available_presence (
 			priv->account_manager, NULL, &msg);
 
-		if (!EMP_STR_EMPTY (msg)) {
+		if (!TPAW_STR_EMPTY (msg)) {
 			gtk_status_icon_set_tooltip_text (priv->icon, msg);
 		}
 		else {
@@ -208,7 +211,7 @@ status_icon_set_visibility (EmpathyStatusIcon *icon,
 	if (!visible) {
 		gtk_widget_hide (priv->window);
 	} else {
-		empathy_window_present (GTK_WINDOW (priv->window));
+		tpaw_window_present (GTK_WINDOW (priv->window));
 	}
 }
 
@@ -351,7 +354,7 @@ status_icon_create_menu (EmpathyStatusIcon *icon)
 	gchar                 *filename;
 
 	filename = empathy_file_lookup ("empathy-status-icon.ui", "src");
-	gui = empathy_builder_get_file (filename,
+	gui = tpaw_builder_get_file (filename,
 					"ui_manager", &priv->ui_manager,
 					"menu", &priv->popup_menu,
 					"show_list", &priv->show_window_item,
@@ -360,7 +363,7 @@ status_icon_create_menu (EmpathyStatusIcon *icon)
 				       NULL);
 	g_free (filename);
 
-	empathy_builder_connect (gui, icon,
+	tpaw_builder_connect (gui, icon,
 			      "show_list", "toggled", status_icon_show_hide_window_cb,
 			      "new_message", "activate", status_icon_new_message_cb,
 			      "new_call", "activate", status_icon_new_call_cb,
