@@ -1027,16 +1027,18 @@ tpaw_account_settings_set (TpawAccountSettings *settings,
   g_return_if_fail (param != NULL);
   g_return_if_fail (v != NULL);
 
+  g_variant_ref_sink (v);
+
   if (!tp_strdiff (param, "password") && settings->priv->supports_sasl &&
       g_variant_is_of_type (v, G_VARIANT_TYPE_STRING))
     {
       g_free (settings->priv->password);
       settings->priv->password = g_variant_dup_string (v, NULL);
+      g_variant_unref (v);
     }
   else
     {
-      g_hash_table_insert (settings->priv->parameters, g_strdup (param),
-          g_variant_ref_sink (v));
+      g_hash_table_insert (settings->priv->parameters, g_strdup (param), v);
     }
 
   account_settings_remove_from_unset (settings, param);
@@ -1081,6 +1083,7 @@ tpaw_account_settings_set_display_name_async (
     {
       /* Nothing to do */
       g_simple_async_result_complete_in_idle (result);
+      g_object_unref (result);
       return;
     }
 
@@ -1090,6 +1093,7 @@ tpaw_account_settings_set_display_name_async (
   if (settings->priv->account == NULL)
     {
       g_simple_async_result_complete_in_idle (result);
+      g_object_unref (result);
       return;
     }
 
@@ -1157,6 +1161,7 @@ tpaw_account_settings_set_icon_name_async (
       settings->priv->icon_name = g_strdup (name);
 
       g_simple_async_result_complete_in_idle (result);
+      g_object_unref (result);
 
       return;
     }
@@ -1404,6 +1409,7 @@ tpaw_account_settings_do_create_account (TpawAccountSettings *self)
 
   tp_account_request_create_account_async (account_req,
       tpaw_account_settings_created_cb, self);
+  g_object_unref (account_req);
 }
 
 static GVariant *
